%define name python
%define ver 1.5.2
%define rel 7mdk
%define idlever 0.5

Summary: An interpreted, interactive object-oriented programming language.
Name: %{name}
Version: %{ver}
Release: %{rel}
Copyright: distributable
Group: Development/Python
Source0: ftp://ftp.python.org/pub/python/src/py152.tar.bz2
Source1: Python-Doc.tar.bz2
Source2: idle
Source3: modulator
Source4: pynche
Source5: idle-%{idlever}.tar.bz2
Patch0: python-1.5.2-config.patch.bz2
Patch1: python-1.4-gccbug.patch.bz2
Patch2: Python-1.5.1-nosed.patch.bz2
Patch3: python-1.5.2-dl-global.patch.bz2
Patch4: python-1.5.2-pythonpath.patch.bz2
URL: http://www.python.org/
Icon: python-logo.xpm
Buildroot: /var/tmp/python-root
Conflicts: tkinter < %{PACKAGE_VERSION}
BuildRequires: gmp-devel tix tk tcl
Requires: tkinter

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to the
Tix widget set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.

%package devel
Summary: The libraries and header files needed for Python development.
Summary(de): Libraries und Header-Dateien fuer Python-Entwicklung.
Icon: python-devel-logo.xpm
Requires: python = %{ver}
Group: Development/Python

%description devel
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install python-devel if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.

%package docs
Summary: Documentation for the Python programming language.
Summary(de): Dokumentation zur Python-Programmiersprache.
Icon: python-docs-logo.xpm
Group: Development/Python

%description docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in LaTeX source files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%package -n tkinter
Summary: A graphical user interface for the Python scripting language.
Summary(de): Graphisches User-interface zur Python-Skriptsprache
Group: Development/Python
Icon: python-tkinter-logo.xpm
Requires: libtcl8.0.so libtk8.0.so
Requires: python = %{PACKAGE_VERSION}

%description -n tkinter
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.

%prep
%setup -q -n Python-%{ver} -a1
%patch0 -p1 -b .config
%patch2 -p1 -b .nosed
%patch3 -p1 -b .global
%patch4 -p1 -b .pythonpath
find . -name "*.nosed" -exec rm -f {} \;

echo ': ${LDSHARED='gcc -shared'}' > config.cache
echo ': ${LINKFORSHARED='-rdynamic'}' >> config.cache
echo ': ${CCSHARED='-fPIC'}' >> config.cache

cp Lib/lib-old/rand.py Lib

%build
OPT="$RPM_OPT_FLAGS"
export OPT
MACHDEP=linux-$RPM_ARCH ./configure --prefix=/usr --with-threads

LDFLAGS=-s make 

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/{bin,lib}
make install prefix=$RPM_BUILD_ROOT/usr
strip $RPM_BUILD_ROOT/usr/bin/python

# tools
# idle
mkdir -p $RPM_BUILD_ROOT/usr/lib/python1.5/site-packages
install -m 755 %{SOURCE2} $RPM_BUILD_ROOT/usr/bin/idle
(set -e
cd $RPM_BUILD_ROOT/usr/lib/python1.5/site-packages
bzcat %{SOURCE5} | tar xf -
mv idle-%{idlever} idle
)

#modulator
install -m 755 $RPM_SOURCE_DIR/modulator $RPM_BUILD_ROOT/usr/bin/modulator
cp -r Tools/modulator \
  $RPM_BUILD_ROOT/usr/lib/python1.5/site-packages/

#pynche
install -m 755 $RPM_SOURCE_DIR/pynche $RPM_BUILD_ROOT/usr/bin/pynche
rm -f Tools/pynche/*.pyw
cp -r Tools/pynche \
  $RPM_BUILD_ROOT/usr/lib/python1.5/site-packages/

ln -f Tools/modulator/README Tools/modulator/README.modulator
ln -f Tools/pynche/README Tools/pynche/README.pynche

rm -f modules-list.full
for n in $RPM_BUILD_ROOT/usr/lib/python1.5/*; do
  [ -d $n ] || echo $n
done >> modules-list.full

for mod in $RPM_BUILD_ROOT/usr/lib/python1.5/lib-dynload/* ; do
  [ `basename $mod` = _tkinter.so ] || echo $mod
done >> modules-list.full
sed -e "s|$RPM_BUILD_ROOT||g" < modules-list.full > modules-list

#get files list for python-tools
DIR1=$RPM_BUILD_ROOT/usr/lib/python1.5/site-packages/pynche
DIR2=$RPM_BUILD_ROOT/usr/lib/python1.5/site-packages/idle
DIR3=$RPM_BUILD_ROOT/usr/lib/python1.5/site-packages/modulator

find $DIR1 -type f | sed -e "s#^$RPM_BUILD_ROOT##g" > python-tools.files
find $DIR2 -type f | sed -e "s#^$RPM_BUILD_ROOT##g" >> python-tools.files
find $DIR3 -type f | sed -e "s#^$RPM_BUILD_ROOT##g" >> python-tools.files

# Menu support
mkdir -p $RPM_BUILD_ROOT/usr/lib/menu
cat > $RPM_BUILD_ROOT/usr/lib/menu/%{name} << EOF
?package(%{name}): needs=text section="Applications/Development/Interpreters" title=Python command=python
?package(%{name}): needs=x11 section="Applications/Development/Development environments" title=IDLE command=idle
EOF

%clean
rm -rf $RPM_BUILD_ROOT
rm -f modules-list modules-list.full

%files -f modules-list
%defattr(-,root,root,755)
/usr/bin/*
%dir /usr/lib/python1.5
/usr/lib/python1.5/plat-linux-%{_arch}
/usr/lib/python1.5/lib-stdwin
%dir /usr/lib/python1.5/lib-dynload
/usr/lib/python1.5/site-packages/pynche
/usr/lib/python1.5/site-packages/idle
/usr/lib/python1.5/site-packages/modulator
/usr/lib/menu/%{name}

%files devel
%defattr(-,root,root,755)
/usr/lib/python*/test
/usr/lib/python*/config
/usr/include/python1.5

%files docs
%defattr(-,root,root,755)
%doc Misc/COPYRIGHT Misc/NEWS Misc/HYPE Misc/README Misc/cheatsheet Misc/BLURB* 
%doc Misc/HISTORY Doc

%files -n tkinter
%defattr(-,root,root,755)
/usr/lib/python1.5/lib-tk
/usr/lib/python1.5/lib-dynload/_tkinter.so

%post

[ -x /usr/bin/update-menus ] && /usr/bin/update-menus

%postun

[ "$1" = 0 -a -x /usr/bin/update-menus ] && /usr/bin/update-menus

%changelog
* Tue May  9 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-7mdk
- added locale module.

* Thu Mar 30 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-6mdk
- menu

* Tue Mar  7 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-5mdk
- idle 0.5.
- compiled with optimization.

* Fri Jan 14 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-4mdk

- added a BuildRequires.

* Sat Dec 4 1999 Florent Villard <warly@mandrakesoft.com>
- add idle, pynche and modulator in the package

* Tue Oct 19 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Merge with redhat changes.
- added modulator, and pynche to the python-tools package(r)
- using a files list in the %files section for python-tools(r)
- added conflicts/requires between subpackages so that you cannot
  have an older tkinter installed with a new python.(r)
- added more tools(r)
- rebuild to fix broken tkinter.(r)
- fixed bogus /usr/local/bin/python requirements.(r)
- added patch to import global symbols until we get libtool patched(r)

* Fri Aug 20 1999 Pablo Saratxaga <pablo@mandrakesoft.com>
- updated to 1.5.2
- updated patches
- use macro %%{_arch} instead of %%{_target_cpu} for file paths

* Tue Apr 13 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Remove the dbm support (doen't work with GLBC2.1)

* Sat Apr 10 1999 Bernhard Rosenkraenzer <bero@linux-mandrake.com>
- Mandrake adaptions
- add de locale
- fix handling of RPM_OPT_FLAGS

* Thu Feb 11 1999 Michael Johnson <johnsonm@redhat.com>
- added mpzmodule at user request (uses gmp)
- added bsddbmodule at user request (uses db 1.85 interface)

* Mon Feb 08 1999 Michael Johnson <johnsonm@redhat.com>
- add --with-threads at user request
- clean up spec file

* Fri Jan 08 1999 Michael K. Johnson <johnsonm@redhat.com>
- New libc changes ndbm.h to db1/ndbm.h and -ldb to -ldb1

* Thu Sep  3 1998 Jeff Johnson <jbj@redhat.com>
- recompile for RH 5.2.

* Wed May 06 1998 Cristian Gafton <gafton@redhat.com>
- python-docs used to require /usr/bin/sed. Changed to /bin/sed instead

* Wed Apr 29 1998 Cristian Gafton <gafton@redhat.com>
- fixed the spec file for version 1.5.1
- buildroot (!)

* Mon Apr 20 1998 Michael K. Johnson <johnsonm@redhat.com>
- updated to python 1.5.1
- created our own Python-Doc tar file from 1.5 to substitute for the
  not-yet-released Doc package.
- build _tkinter properly
- use readline again
- build crypt module again
- install rand replacement module
- added a few modules

* Thu Apr 09 1998 Erik Troan <ewt@redhat.com>
- updated to python 1.5
- made /usr/lib/python1.5 file list automatically generated

* Tue Nov 04 1997 Michael K. Johnson <johnsonm@redhat.com>
- Fixed dependencies for python and tkinter

* Mon Nov 03 1997 Michael K. Johnson <johnsonm@redhat.com>
- pulled out tk-related stuff into tkinter package

* Fri Oct 10 1997 Erik Troan <ewt@redhat.com>
- bunches of scripts used /usr/local/bin/python instead of /usr/bin/python

* Tue Sep 30 1997 Erik Troan <ewt@redhat.com>
- updated for tcl/tk 8.0

* Thu Jul 10 1997 Erik Troan <ewt@redhat.com>
- built against glibc
